@@ -11,7 +11,8 @@ sys.path.insert(0, os.path.abspath("../../src/pymadng/"))
 project = 'PyMAD-NG'
 copyright = '2022, Joshua Gray, Laurent Deniau'
 author = 'Joshua Gray, Laurent Deniau'
-release = '0.2.5'
+import pymadng
+release = pymadng.__version__
 
 # -- General configuration ---------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration
